#
# spec file for package cosmic-files
#
# Copyright (c) 2025 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%define         appname com.system76.CosmicFiles
Name:           cosmic-files
Version:        1.0.0~alpha6+1
Release:        1.2
Summary:        COSMIC file manager
License:        GPL-3.0-only
URL:            https://github.com/pop-os/cosmic-files
Source0:        %{name}-%{version}.tar.zst
Source1:        vendor.tar.zst
BuildRequires:  cargo-packaging
BuildRequires:  git-core
BuildRequires:  hicolor-icon-theme
BuildRequires:  just
BuildRequires:  pkgconfig
BuildRequires:  rust >= 1.80
BuildRequires:  pkgconfig(glib-2.0)
BuildRequires:  pkgconfig(xkbcommon)

%description
File manager for the COSMIC desktop environment

%prep
%autosetup -a1

%build
just build-release

%install
just rootdir=%{buildroot} prefix=%{_prefix} install

%check
# take too long on OBS, gets killed
# %%{cargo_test}

%files
%license LICENSE
%doc README.md
%{_bindir}/%{name}
%{_bindir}/%{name}-applet
%{_datadir}/applications/%{appname}.desktop
%{_datadir}/icons/hicolor/*/apps/%{appname}.svg
%{_datadir}/metainfo/%{appname}.metainfo.xml

%changelog
* Sat Feb 22 2025 rrahl0@opensuse.org
- Update to version 1.0.0~alpha6+1:
  * Move dbus-config to optional feature
  * Fix thumbnails
  * Removing unused import
  * Change calculation of virtual drag area to work with subscription by not relying on mouse movements
  * perf: update libcosmic to improve window resize performance
  * Fixing issue with scroll speed subscription not working in dev profile, removing speed code as redundant
  * i18n(pl): update Polish translation
  * chore: upgrade dependencies
  * Moving autoscroll to a subscription on fixed timer + calculating speed based off of distance to edge
  * i18n(nl) update Dutch translation
  * Fixing issue with x-axis desyncing
  * Fixing issue where swapping between list & grid view 'desync' the virtual cursor
  * Fixing some jankiness by decoupling scroll offset vs 'virtual' cursor position & resetting after drag end
  * Implementing 'virtual cursor offset' to help track & dynamically update drag rect
  * Adding in resize listener for gridview
  * Adding in new functionality to scroll the file window when dragging outside the viewport of the scrollable
  * Update Hungarian translations
  * i18n(de): add German translation
  * fix: set the active tab in desktop mode when the window is focused
  * chore: update libcosmic with mmap threshold fix
  * Improve permissions descriptions
  * Add mode samples
  * fix(applet): set mmap threshold to lower memory usage
  * Fix unit test - fedora build.
  * i18n(nl) update and improve Dutch translation
  * Update cosmic_files.ftl PL translation Password Grid Spacing
  * Adjust style of completions again
  * Do not show completion if already on an existing path
  * Limit completions to 8
  * Improve style of completions
  * Path completion
  * improv(preview_view): set max height for previews
  * Update Hungarian translations
  * Add icon size and grid spacing for desktop, fixes #751
  * Set select_focus when selecting by name or path
  * Fixing issue where a tab tries to read lines from a .hidden directory
  * Polish translation for MetaInfo
  * fix: set M_MMAP_THRESHOLD to lower memory usage significantly
  * Format
  * adding in cancel action for password required dialog
  * VecDeque makes more sense to maintain order of operations
  * quick cleanup to some untranslated strings, moving zip extract dir creation order
  * i18n(pt-BR): update translations
  * adding in support to extract/compress zip files with passwords
  * i18n(nl) update Dutch translation
  * chore(clippy): `tab.rs`
  * Focus text input when in NetworkAuth modal
  * Do not display already-exists message when name isn't changed
  * chore(clippy): `app.rs`, `mime_app.rs`
  * Update the Hungarian translation with the desktop files
  * Update Hungarian translations
  * Update cosmic_files.ftl
  * Clean up mime app handling and make it possible to set default application
  * Remove use of expect to fix minimum rust version
  * Handle org.freedesktop.FileManager1 in cosmic-files-applet
  * Support URL arguments
  * If file is passed on command line, show parent folder and select it
  * chore(clippy): config, dialog, menu
  * chore(clippy): mime_app, operation, mounter
  * chore(clippy): `mouse_area`, `controller` & more
  * chore(clippy): `thumbnailer.rs`, two files in operation
  * Allow drop to Desktop, fixes #597
  * Add on_submit handler to NetworkAuth dialog
  * Only display 'Connect anonymously' when available
- switch to obs_scm
* Sat Jan 18 2025 rrahl0@opensuse.org
- Update to version 1.0.0~alpha5+3:
  * Replace use of blocking function on search results channel, fixes #601
  * Fix resetting shift select range
  * Add move to first/last item with home/end keys
  * always check if a search is active when rescanning (#712)
  * Update dependencies
  * Add more plain text mime types when copying files
  * Fix left clicking in empty folder to clear context menu
  * Close context menu when window loses focus
  * Minor Polish translation improvements
  * fix: Strip more file names in extractor
  * perf: optimized cosmic-freedesktop-icons
  * Update dependencies
* Fri Jan 10 2025 rrahl0@opensuse.org
- Update to version 1.0.0~alpha5+1:
  * Update dependencies
  * Update cosmic_files.ftl (#727)
  * Add Dutch translation (#724)
  * Fix crash for dialog in debug mode
  * Fix 'New folder...' context menu item in save dialog
  * Enable `Open item location` for Recents
  * update search on events
  * use parent of file/folder instead of tab location for renaming
  * Update Turkish translation
  * Update Turkish translation
  * i18n(de): add German translation
  * i18n pt-BR translation update
  * i18n pt-BR translation update
  * Add Danish translation
  * Fix Show Hidden Files
  * Add Thai translation
  * Unset `show_details` on close too
* Thu Dec  5 2024 rrahl0@opensuse.org
- Update to version 1.0.0~alpha4+0:
  * Unset `show_details` on escape
  * refactor: overlap handling for surfaces that occupy a corner
  * feat: avoid overlap with panel
  * update libcosmic
  * Update cosmic_files.ftl zh-CN and fix several translation errors
* Thu Oct 31 2024 Richard Rahl <rrahl0@opensuse.org>
- update to 1.0.0~alpha3:
  * removed std err pipe
  * run AppImage files from cosmic-files
  * fix(extract): correctly append copy suffix for existing folder names
  * fix(extract): preserve full folder names during extraction
  * Improve move operations
  * Disable menu items when not available
  * Fix build when desktop feature is disabled
  * Preserve selections through external changes
  * Backspace to go back
  * Scroll to the top after changing location
  * Correct input argument for thumbnailer
  * Generically support external thumbnailers
  * Add support for evince thumbnailer
  * updated translations
* Wed Sep 25 2024 Richard Rahl <rrahl0@opensuse.org>
- update to 1.0.0~alpha2:
  * fix: add padding to context menu divider
  * feat: add missing file menu entries
  * Continue operations in the background if the window is closed
  * fix: add settings keybind
  * Clear and close search field on nav
  * Activate navbar selection on init and when switching tabs
  * Sort modified descending on initial click
  * fix icons
  * Fix scrolling item into view when using arrow keys
  * Fix breadcrumbs to use pointer mouse cursor
  * Don't focus tab when opening folder in new tab
  * Select previous directory when navigating back
  * Add Open item location for search results, fixes
  * Show symlinked directories as directories
  * Enable extracting zip files to current folder
  * removed examples from cargo.toml
  * Display file ownership and permissions
  * fix app name
  * updated translations
* Thu Aug  8 2024 Richard Rahl <rrahl0@opensuse.org>
- standardize packaging with also fixes for miscellaneous hardcoding
  filenames, using @PARENT_TAG where applicable, and be more specific
  with files in the %%files section (so no non-wanted files are getting
  added
* Wed Aug  7 2024 Richard Rahl <rrahl0@opensuse.org>
- update to 1.0.0~alpha1:
  * fix: don't scroll sorting headings
  * undo toaster
  * update translations
- enable leap (thanks to vyvir)
* Sun Jul 14 2024 Richard Rahl <rrahl0@opensuse.org>
- disable tests for now, as they get killed on OBS
* Wed Mar 13 2024 Richard Rahl <rrahl0@proton.me>
- initial packaging
